@@ -1,4 +1,5 @@
 from ...precomputed.mesh import PrecomputedMeshMetadata
 
 class GrapheneMeshMetadata(PrecomputedMeshMetadata):
-  pass
\ No newline at end of file
+  def sharding(self, layer_id):
+    return self.info['sharding'][str(layer_id)]
\ No newline at end of file
